@@ -68,9 +68,8 @@ class LocalPath(common.FSPathBase, PlatformMixin):
         elif isinstance(path, str):
             self.strpath = os.path.abspath(os.path.normpath(str(path)))
         else:
-            raise ValueError(
-                "can only pass None, Path instances "
-                "or non-empty strings to LocalPath")
+            raise ValueError("can only pass None, Path instances "
+                             "or non-empty strings to LocalPath")
         assert isinstance(self.strpath, str)
         return self
 
@@ -401,8 +400,8 @@ class LocalPath(common.FSPathBase, PlatformMixin):
                     self._prependsyspath(pkgpath.dirpath())
                 pkg = __import__(pkgpath.basename, None, None, [])
                 
-                if hasattr(pkg, '__package__'):
-                    modname = pkg.__package__.getimportname(self)
+                if hasattr(pkg, '__pkg__'):
+                    modname = pkg.__pkg__.getimportname(self)
                     assert modname is not None, "package %s doesn't know %s" % (
                                                 pkg.__name__, self)
                 
